bayespy.nodes.SwitchingGaussianMarkovChain
==========================================

.. currentmodule:: bayespy.nodes

.. autoclass:: SwitchingGaussianMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~SwitchingGaussianMarkovChain.__init__
      ~SwitchingGaussianMarkovChain.add_plate_axis
      ~SwitchingGaussianMarkovChain.broadcasting_multiplier
      ~SwitchingGaussianMarkovChain.delete
      ~SwitchingGaussianMarkovChain.get_gradient
      ~SwitchingGaussianMarkovChain.get_mask
      ~SwitchingGaussianMarkovChain.get_moments
      ~SwitchingGaussianMarkovChain.get_parameters
      ~SwitchingGaussianMarkovChain.get_riemannian_gradient
      ~SwitchingGaussianMarkovChain.get_shape
      ~SwitchingGaussianMarkovChain.has_plotter
      ~SwitchingGaussianMarkovChain.initialize_from_parameters
      ~SwitchingGaussianMarkovChain.initialize_from_prior
      ~SwitchingGaussianMarkovChain.initialize_from_random
      ~SwitchingGaussianMarkovChain.initialize_from_value
      ~SwitchingGaussianMarkovChain.load
      ~SwitchingGaussianMarkovChain.logpdf
      ~SwitchingGaussianMarkovChain.lower_bound_contribution
      ~SwitchingGaussianMarkovChain.lowerbound
      ~SwitchingGaussianMarkovChain.move_plates
      ~SwitchingGaussianMarkovChain.observe
      ~SwitchingGaussianMarkovChain.pdf
      ~SwitchingGaussianMarkovChain.plot
      ~SwitchingGaussianMarkovChain.random
      ~SwitchingGaussianMarkovChain.rotate
      ~SwitchingGaussianMarkovChain.save
      ~SwitchingGaussianMarkovChain.set_parameters
      ~SwitchingGaussianMarkovChain.set_plotter
      ~SwitchingGaussianMarkovChain.show
      ~SwitchingGaussianMarkovChain.unobserve
      ~SwitchingGaussianMarkovChain.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~SwitchingGaussianMarkovChain.dims
      ~SwitchingGaussianMarkovChain.plates
      ~SwitchingGaussianMarkovChain.plates_multiplier
   
   